@@ -5,39 +5,52 @@ OC.L10N.register(
     "All contacts" : "Kõik kontaktid",
     "Contacts" : "Kontaktid",
     "Loading contacts …" : "Laen kontakte ...",
-    "Download" : "Lae alla",
-    "Groups" : "Grupid",
-    "Group name" : "Grupi nimi",
     "Rename" : "Nimeta ümber",
-    "Enabled" : "Lubatud",
-    "Disabled" : "Keelatud",
+    "Send email" : "Saada kiri",
     "Delete" : "Kustuta",
+    "Download" : "Lae alla",
     "Copy link" : "Kopeeri link",
+    "_%n contact_::_%n contacts_" : ["%n kontakt","%nkontakti"],
+    "_%n group_::_%n groups_" : ["%n grupp","%n gruppi"],
     "Share with users or groups" : "Jaga kasutajate või gruppidega",
     "No users or groups" : "Ei ole kasutajaid või gruppe",
     "can edit" : "saab redigeerida",
+    "Add" : "Lisa",
     "First name" : "Eesnimi",
     "Last name" : "Perekonnanimi",
     "Display name" : "Kuvatav nimi",
     "Last modified" : "Viimati muudetud",
+    "Password protection" : "Password protection",
+    "Save" : "Salvesta",
+    "Description" : "Kirjeldus",
+    "Settings" : "Settings",
+    "Cancel" : "Loobu",
     "Delete picture" : "Kustuta pilt",
     "Invalid image" : "Vigane pilt",
     "Name" : "Nimi",
     "Title" : "Pealkiri",
-    "Cancel" : "Loobu",
     "Address book" : "Aadressiraamat",
-    "New contact" : "Uus kontakt",
+    "Search contacts …" : "Otsi kontakte",
     "No results" : "Vasteid ei leitud",
+    "Pending" : "Ootel",
+    "None" : "Pole",
+    "New contact" : "Uus kontakt",
     "Close" : "Sulge",
     "Import" : "Impordi",
     "Not grouped" : "Pole grupeeritud",
+    "User" : "Kasutaja",
+    "Group" : "Grupp",
     "Email" : "E-post",
     "Contact" : "Kontakt",
-    "Nickname" : "Hüüdnimi",
+    "Member" : "Liige",
+    "Moderator" : "Moderaator",
+    "Admin" : "Admin",
+    "Owner" : "Omanik",
     "Detailed name" : "Üksikasjalik nimi",
     "Additional names" : "Lisanimed",
     "Prefix" : "Eesliide",
     "Suffix" : "Järelliide",
+    "Nickname" : "Hüüdnimi",
     "Notes" : "Märkmed",
     "Website" : "Veebileht",
     "Location" : "Asukoht",
@@ -76,12 +89,11 @@ OC.L10N.register(
     "Relative" : "Sugulane",
     "Friend" : "Sõber",
     "Colleague" : "Kolleeg",
-    "Manager" : "Juht",
     "Assistant" : "Assistent",
     "Gender" : "Sugu",
     "Female" : "Naine",
     "Male" : "Mees",
-    "None" : "Pole",
-    "Unknown" : "Teadmata"
+    "Unknown" : "Teadmata",
+    "Manager" : "Juht"
 },
 "nplurals=2; plural=(n != 1);");
