@@ -4,27 +4,28 @@ OC.L10N.register(
     "Details" : "Detalios",
     "All contacts" : "Tote contactos",
     "Contacts" : "Contactos",
-    "Send email" : "Inviar message de e-posta",
-    "Download" : "Discargar",
     "Rename" : "Renominar",
-    "Enabled" : "Activate",
+    "Send email" : "Inviar message de e-posta",
     "Delete" : "Deler",
+    "Download" : "Discargar",
     "Copy link" : "Copiar ligamine",
     "Share with users or groups" : "Compartir con usatores o gruppos",
     "can edit" : "pote modificar",
+    "Add" : "Adder",
     "First name" : "Prime nomine",
     "Last name" : "Ultime nomine",
     "Display name" : "Monstrar nomine",
     "Password protection" : "Password protection",
     "Save" : "Salveguardar",
     "Description" : "Description",
+    "Settings" : "Settings",
     "Cancel" : "Cancellar",
     "Invalid image" : "Imagine invalide",
     "Name" : "Nomine",
     "Title" : "Titulo",
-    "New contact" : "Nove contacto",
     "Pending" : "Pendente",
     "None" : "Nulle",
+    "New contact" : "Nove contacto",
     "Close" : "Clauder",
     "Import" : "Importar",
     "Not grouped" : "Non gruppate",
@@ -32,7 +33,6 @@ OC.L10N.register(
     "Group" : "Gruppo",
     "Email" : "E-posta",
     "Owner" : "Owner",
-    "Users" : "Usatores",
     "Detailed name" : "Nomine detaliate",
     "Additional names" : "Nomines additional",
     "Prefix" : "Prefixo",
