@@ -4,17 +4,16 @@ OC.L10N.register(
     "Details" : "Detil",
     "All contacts" : "Semua kontak",
     "Contacts" : "Kontak",
-    "Download" : "Unduh",
-    "Send email" : "Kirim surel",
-    "Groups" : "Grup",
-    "Group name" : "Nama grup",
+    "A contacts app for Nextcloud" : "Sebuah aplikasi kontak untuk Nextcloud",
     "Rename" : "Ubah nama",
-    "Enabled" : "Diaktifkan",
+    "Send email" : "Kirim surel",
     "Delete" : "Hapus",
+    "Download" : "Unduh",
     "Copy link" : "Salin tautan",
     "Share with users or groups" : "Bagi dengan pengguna atau grup",
     "No users or groups" : "Tidak ada pengguna atau grup",
     "can edit" : "dapat menyunting",
+    "Add" : "Masukkan",
     "First name" : "Nama depan",
     "Last name" : "Nama belakang",
     "Display name" : "Nama tampilan",
@@ -22,28 +21,29 @@ OC.L10N.register(
     "Password protection" : "Password protection",
     "Save" : "Simpan",
     "Description" : "Deskrisi",
+    "Settings" : "Settings",
+    "Cancel" : "Membatalkan",
     "Invalid image" : "Gambar tidak sah",
     "Name" : "Nama",
     "Title" : "Judul",
-    "Cancel" : "Membatalkan",
-    "New contact" : "Kontak baru",
     "Search contacts …" : "Cari kontak ...",
     "No results" : "Tidak ada hasil",
     "Pending" : "Tunggu",
+    "None" : "Tidak ada",
+    "New contact" : "Kontak baru",
     "Close" : "Tutup",
     "Import" : "Impor",
     "Not grouped" : "Tidak dikelompokkan",
     "User" : "Pengguna",
     "Group" : "Grup",
-    "Email" : "Email",
+    "Email" : "Surel",
     "Admin" : "Admin",
     "Owner" : "Owner",
-    "Users" : "Pengguna",
-    "Nickname" : "Nama panggilan",
     "Detailed name" : "Nama lengkap",
     "Additional names" : "Nama tambahan",
     "Prefix" : "Prefix",
     "Suffix" : "Suffix",
+    "Nickname" : "Nama panggilan",
     "Notes" : "Catatan",
     "Website" : "Situs Web",
     "Location" : "Lokasi",
@@ -69,7 +69,6 @@ OC.L10N.register(
     "Pager" : "Pager",
     "Voice" : "Suara",
     "Social network" : "Media sosial",
-    "None" : "Tidak ada",
     "Unknown" : "Tidak diketahui"
 },
 "nplurals=1; plural=0;");
