@@ -5,19 +5,15 @@ OC.L10N.register(
     "All contacts" : "ყველა კონტაქტი",
     "Contacts" : "კონტაქტები",
     "Loading contacts …" : "კონტაქტების ჩატვირთვა ...",
-    "Delete circle" : "წრის გაუქმება",
-    "Download" : "ჩამოტვირთვა",
-    "Send email" : "ელ-წერილის გაგზავნა",
-    "Groups" : "ჯგუფები",
-    "Group name" : "ჯგუფის სახელი",
-    "Circles" : "წრეები",
-    "Create a new circle" : "შექმენით წრე",
+    "General settings" : "მთავარი პარამეტრები",
     "Rename" : "სახელის შეცვლა",
-    "Enabled" : "მოქმედია",
+    "Send email" : "ელ-წერილის გაგზავნა",
     "Delete" : "გაუქმება",
+    "Download" : "ჩამოტვირთვა",
     "Copy link" : "ბმულის კოპირება",
     "Share with users or groups" : "გაზიარება მოხმარებლებთან ან ჯგუფებთან",
     "can edit" : "შეუძლია შეცვლა",
+    "Add" : "დამატება",
     "First name" : "სახელი",
     "Last name" : "გვარი",
     "Display name" : "დისპლეი სახელი",
@@ -25,20 +21,20 @@ OC.L10N.register(
     "Password protection" : "პაროლით თავდაცვა",
     "Save" : "შენახვა",
     "Description" : "აღწერილობა",
+    "Settings" : "Settings",
+    "Cancel" : "უარყოფა",
     "Invalid image" : "არასწორი სურათი",
     "Name" : "სახელი",
     "Title" : "სათაური",
-    "Cancel" : "უარყოფა",
     "Address book" : "მისამართების წიგნი",
-    "New contact" : "ახალი კონტაქტი",
     "Search contacts …" : "მოძებნეთ კონტაქტები ...",
     "No results" : "შედეგები არაა",
-    "Personal circle" : "პირადი წრე",
     "Pending" : "მოლოდინში",
+    "None" : "არც ერთი",
+    "New contact" : "ახალი კონტაქტი",
     "Close" : "დახურვა",
     "Import" : "იმპორტი",
     "Not grouped" : "არაა დაჯგუფებული",
-    "Circle" : "წრე",
     "User" : "მომხმარებელი",
     "Group" : "ჯგუფი",
     "Email" : "ელ-ფოსტა",
@@ -47,12 +43,11 @@ OC.L10N.register(
     "Moderator" : "მოდერატორი",
     "Admin" : "ადმინისტრატორი",
     "Owner" : "მფლობელი",
-    "Users" : "მომხმარებლები",
-    "Nickname" : "ნიკნეიმი",
     "Detailed name" : "დეტალური სახელი",
     "Additional names" : "დამატებითი სახელები",
     "Prefix" : "პრეფიქსი",
     "Suffix" : "სუფიქსი",
+    "Nickname" : "ნიკნეიმი",
     "Notes" : "შენიშვნები",
     "Website" : "ვებ-საიტი",
     "Location" : "ადგილმდებარეობა",
@@ -80,7 +75,6 @@ OC.L10N.register(
     "Voice" : "ხმა",
     "Car" : "მაქნანა",
     "Work pager" : "სამუშაო პეიჯერი",
-    "Manager" : "მენეჯერი",
     "Social network" : "სოციალური ქსელი",
     "Spouse" : "მეუღლე",
     "Child" : "შვილი",
@@ -96,7 +90,7 @@ OC.L10N.register(
     "Gender" : "სქესი",
     "Female" : "მდედორობითი",
     "Male" : "მამრობითი",
-    "None" : "არც ერთი",
-    "Unknown" : "ამოუცნობი"
+    "Unknown" : "ამოუცნობი",
+    "Manager" : "მენეჯერი"
 },
 "nplurals=2; plural=(n!=1);");
