@@ -3,15 +3,16 @@ OC.L10N.register(
     {
     "Details" : "ព័ត៌មាន​លម្អិត",
     "Contacts" : "ទំនាក់​ទំនង",
-    "Send email" : "ផ្ញើ​អ៊ីមែល",
-    "Download" : "ទាញយក",
     "Rename" : "ប្ដូរ​ឈ្មោះ",
-    "Enabled" : "បាន​បើក",
+    "Send email" : "ផ្ញើ​អ៊ីមែល",
     "Delete" : "លុប",
+    "Download" : "ទាញយក",
     "can edit" : "អាច​កែប្រែ",
+    "Add" : "បញ្ចូល",
     "Password protection" : "Password protection",
     "Save" : "រក្សាទុក",
     "Description" : "ការ​អធិប្បាយ",
+    "Settings" : "Settings",
     "Cancel" : "បោះបង់",
     "Invalid image" : "រូបភាព​មិន​ត្រឹម​ត្រូវ",
     "Name" : "ឈ្មោះ",
@@ -27,7 +28,6 @@ OC.L10N.register(
     "Email" : "អ៊ីមែល",
     "Admin" : "អ្នក​គ្រប់​គ្រង",
     "Owner" : "Owner",
-    "Users" : "អ្នកប្រើ",
     "Notes" : "កំណត់​ចំណាំ",
     "Location" : "ទីតាំង",
     "Work" : "ធ្វើការ",
