@@ -8,6 +8,8 @@ OC.L10N.register(
     "Copy to full name" : "คัดลอกไปยังชื่อเต็ม",
     "Omit year" : "ละเว้นปี",
     "Allow updating avatars from social media" : "อนุญาตให้อัปเดตภาพแทนตัวจากโซเชียลมีเดีย",
+    "Please select a team" : "โปรดเลือกทีม",
+    "Loading team…" : "กำลังโหลด ทีม",
     "Loading contacts …" : "กำลังโหลดรายชื่อ …",
     "There are no contacts yet" : "ยังไม่มีรายชื่อผู้ติดต่อ",
     "Create contact" : "สร้างรายชื่อ",
@@ -15,26 +17,26 @@ OC.L10N.register(
     "Create contacts" : "สร้างรายชื่อ",
     "Add contacts" : "เพิ่มรายชื่อ",
     "Loading …" : "กำลังโหลด …",
-    "Add member" : "เพิ่มสมาชิก",
     "Contacts settings" : "การตั้งค่ารายชื่อ",
     "General settings" : "การตั้งค่าทั่วไป",
     "Update avatars from social media" : "อัปเดตภาพแทนตัวจากโซเชียลมีเดีย",
     "(refreshed once per week)" : "(รีเฟรชใหม่สัปดาห์ละครั้ง)",
     "Address books" : "สมุดรายชื่อ",
+    "Rename" : "เปลี่ยนชื่อ",
     "Send email" : "ส่งอีเมล",
+    "Delete" : "ลบ",
     "Contact groups" : "กลุ่มรายชื่อ",
     "Create a new contact group" : "สร้างกลุ่มรายชื่อใหม่",
     "Contact group name" : "ชื่อของกลุ่มรายชื่อ",
     "Show all groups" : "แสดงกลุ่มทั้งหมด",
     "Collapse groups" : "ย่อกลุ่ม",
     "Download" : "ดาวน์โหลด",
-    "Rename" : "เปลี่ยนชื่อ",
-    "Delete" : "ลบ",
     "Copied" : "คัดลอกแล้ว",
     "Cannot copy" : "ไม่สามารถคัดลอก",
     "Copy link" : "คัดลอกลิงก์",
     "Share with users or groups" : "แชร์กับผู้ใช้หรือกลุ่ม",
     "can edit" : "สามารถแก้ไข",
+    "Add" : "เพิ่ม",
     "First name" : "ชื่อจริง",
     "Last name" : "นามสกุล",
     "Display name" : "ชื่อที่แสดง",
@@ -49,7 +51,6 @@ OC.L10N.register(
     "Cancel" : "ยกเลิก",
     "Upload a new picture" : "อัปโหลดรูปภาพใหม่",
     "Choose from Files" : "เลือกจากไฟล์",
-    "Get from " : "รับจาก",
     "Download picture" : "ดาวน์โหลดรูปภาพ",
     "Delete picture" : "ลบรูปภาพ",
     "Invalid image" : "รูปภาพไม่ถูกต้อง",
@@ -73,7 +74,6 @@ OC.L10N.register(
     "Email" : "อีเมล",
     "Admin" : "ผู้ดูแลระบบ",
     "Owner" : "เจ้าของ",
-    "Users" : "ผู้ใช้",
     "Detailed name" : "ชื่อโดยละเอียด",
     "Additional names" : "ชื่ออื่น ๆ",
     "Prefix" : "คำนำหน้า",
